@@ -14,7 +14,9 @@ shutdown_event = asyncio.Event()
 
 
 def create_grpc_server(descriptor: FileDescriptor):
-  server = aio.server()
+  max_length = 512 * 1024 * 1024
+  server_options = [('grpc.max_send_message_length', max_length), ('grpc.max_receive_message_length', max_length)]
+  server = aio.server(options=server_options)
   server.__dict__['descriptor'] = descriptor
   server.add_insecure_port('[::]:8080')
   health_servicer = health.HealthServicer(experimental_non_blocking=True)
